==> huma_signals-0.1.1.tar.gz: huma_signals-0.1.1/README.md <==
<p align="center">
  <a href="https://huma.finance"><img src="https://user-images.githubusercontent.com/5999398/210867640-95c8944c-fcd0-4199-9f08-b0ae6eda70c0.jpg" alt="Huma Finance" width="500px"></a>
  <h1 align="center">Decentralized Signal Portfolio</h1>
</p>



<p align="center">
  <a href="https://github.com/00labs/huma-signals/actions" target="_blank">
    <img alt="Action Status" src="https://github.com/00labs/huma-signals/actions/workflows/ci.yaml/badge.svg">
  </a>
  <img alt="Version" src="https://img.shields.io/badge/version-0.1.0-blue.svg?cacheSeconds=2592000" />
  <a href="https://docs.huma.finance/" target="_blank">
    <img alt="Documentation" src="https://img.shields.io/badge/documentation-yes-brightgreen.svg" />
  </a>
  <a href="https://discord.gg/7e2fdMSCZr">
    <img alt="" src="https://badgen.net/badge/Join/HUMAnity%20Discord/cyan?icon=discor">
  </a>
  <a href="https://www.gnu.org/licenses/agpl-3.0.en.html" target="_blank">
    <img alt="License: AGPLv3" src="https://img.shields.io/badge/License-AGPLv3-yellow.svg" />
  </a>
  <a href="https://twitter.com/humafinance" target="_blank">
    <img alt="Twitter: humafinance" src="https://img.shields.io/twitter/follow/humafinance.svg?style=social" />
  </a>

The Decentralized Signal Portfolio (DSP) is an open platform that enables access to high-quality signals about a borrower's income, assets, and liabilities. These signals are collected through Signal Adapters hosted on the DSP, which gather data from a variety of on-chain and off-chain sources. Any developer can contribute to the platform by adding a new Signal Adapter for a specific data source.

</p>

## Overview

📜 [Huma Whitepaper](https://docs.huma.finance/)

🏠 [Homepage](https://huma.finance)

## Documentation

For additional guides, examples, and APIs, see the [documentation](./docs/).

## Want to help?

Give a ⭐️ if this project helped you!

Want to file a bug, contribute some code, or improve the documentation? Excellent! Read up on our guidelines for [contributing](.docs/../docs/contributing.md).

## 📝 License

This project is [AGPL v3](https://www.gnu.org/licenses/agpl-3.0.en.html) licensed.

==> huma_signals-0.6.0.tar.gz: huma_signals-0.6.0/README.md <==
<p align="center">
  <a href="https://huma.finance"><img src="https://user-images.githubusercontent.com/5999398/210867640-95c8944c-fcd0-4199-9f08-b0ae6eda70c0.jpg" alt="Huma Finance" width="500px"></a>
  <h1 align="center">Decentralized Signal Portfolio</h1>
</p>

<p align="center">
  <a href="https://github.com/00labs/huma-signals/actions" target="_blank">
    <img alt="Action Status" src="https://github.com/00labs/huma-signals/actions/workflows/ci-main.yml/badge.svg">
  </a>
  <img alt="Version" src="https://img.shields.io/badge/version-0.2.1-blue.svg?cacheSeconds=2592000" />
  <a href="https://docs.huma.finance/" target="_blank">
    <img alt="Documentation" src="https://img.shields.io/badge/documentation-yes-brightgreen.svg" />
  </a>
  <a href="https://discord.gg/7e2fdMSCZr">
    <img alt="" src="https://badgen.net/badge/Join/HUMAnity%20Discord/cyan?icon=discor">
  </a>
  <a href="https://www.gnu.org/licenses/agpl-3.0.en.html" target="_blank">
    <img alt="License: AGPLv3" src="https://img.shields.io/badge/License-AGPLv3-yellow.svg" />
  </a>
  <a href="https://twitter.com/humafinance" target="_blank">
    <img alt="Twitter: humafinance" src="https://img.shields.io/twitter/follow/humafinance.svg?style=social" />
  </a>

The Decentralized Signal Portfolio (DSP) is an open source package that enables access to high-quality signals about a borrower's income, assets, and liabilities. These signals are collected through Signal Adapters, which gather data from a variety of on-chain and off-chain sources. Any developer can contribute to the platform by adding a new Signal Adapter for a specific data source.
</p>

## Overview

📜 [Huma Whitepaper](https://docs.huma.finance/)

🏠 [Homepage](https://huma.finance)

## Documentation

For additional guides, examples, and APIs, see the [documentation](./docs/).

## Want to help?

Give a ⭐️ if this project helped you!

Want to file a bug, contribute some code, or improve the documentation? Excellent! Read up on our guidelines for [contributing](.docs/../docs/contributing.md).

## 📝 License

This project is [AGPL v3](https://www.gnu.org/licenses/agpl-3.0.en.html) licensed.
